@@ -8,7 +8,7 @@ from collections import Mapping, Set, Iterable, Iterator, defaultdict
 from itertools import chain, tee
 from functools import reduce
 
-from .cross import basestring, xrange, izip
+from .cross import basestring, xrange, izip, map, filter, imap, ifilter, PY2
 from .primitives import EMPTY
 from .funcs import identity, partial, compose, complement
 from .funcmakers import wrap_mapper, wrap_selector
@@ -16,7 +16,7 @@ from .seqs import take, ximap, ifilter
 
 
 __all__ = ['empty', 'iteritems',
-           'join', 'merge',
+           'join', 'merge', 'join_with', 'merge_with',
            'walk', 'walk_keys', 'walk_values', 'select', 'select_keys', 'select_values', 'compact',
            'is_distinct', 'all', 'any', 'none', 'one', 'some',
            'zipdict', 'flip', 'project', 'izip_values', 'izip_dicts',
@@ -39,7 +39,7 @@ def _factory(coll, mapper=None):
 def empty(coll):
     return _factory(coll)()
 
-if sys.version_info[0] == 2:
+if PY2:
     def iteritems(coll):
         return coll.iteritems() if hasattr(coll, 'iteritems') else coll
 else:
@@ -76,9 +76,31 @@ def join(colls):
 def merge(*colls):
     return join(colls)
 
-# postponed
-# def conj(coll, *xs):
-#     return merge(coll, xs)
+
+def join_with(f, dicts):
+    dicts = list(dicts)
+    if not dicts:
+        return {}
+    elif len(dicts) == 1:
+        return dicts[0]
+
+    lists = {}
+    for c in dicts:
+        for k, v in iteritems(c):
+            if k in lists:
+                lists[k].append(v)
+            else:
+                lists[k] = [v]
+
+    if f is not list:
+        # kind of walk_values() inplace
+        for k, v in iteritems(lists):
+            lists[k] = f(v)
+
+    return lists
+
+def merge_with(f, *dicts):
+    return join_with(f, dicts)
 
 
 def walk(f, coll):
@@ -205,12 +227,13 @@ def invoke(objects, name, *args, **kwargs):
     return map(methodcaller(name, *args, **kwargs), objects)
 
 
-if sys.version_info[0] == 3:
-    def lwhere(mappings, **cond):
-        return list(where(mappings, **cond))
+# Iterator versions for python 3 interface
+def iwhere(mappings, **cond):
+    match = lambda m: all(m[k] == v for k, v in cond.items())
+    return ifilter(match, mappings)
 
-    def lpluck(key, mappings):
-        return list(pluck(key, mappings))
+def ipluck(key, mappings):
+    return imap(itemgetter(key), mappings)
 
-    def linvoke(objects, name, *args, **kwargs):
-        return list(invoke(objects, name, *args, **kwargs))
+def iinvoke(objects, name, *args, **kwargs):
+    return imap(methodcaller(name, *args, **kwargs), objects)
