@@ -1,9 +1,9 @@
-from collections import Mapping, Sequence, Iterator, Iterable
+from collections import Mapping, Set, Sequence, Iterator, Iterable
 
 from .cross import xrange
 
 
-__all__ = ('isa', 'is_mapping', 'is_seq', 'is_list', 'is_tuple',
+__all__ = ('isa', 'is_mapping', 'is_set', 'is_seq', 'is_list', 'is_tuple',
            'is_seqcoll', 'is_seqcont',
            'iterable', 'is_iter')
 
@@ -12,6 +12,7 @@ def isa(*types):
     return lambda x: isinstance(x, types)
 
 is_mapping = isa(Mapping)
+is_set = isa(Set)
 is_seq = isa(Sequence)
 is_list = isa(list)
 is_tuple = isa(tuple)
